# Licensed under a 3-clause BSD style license - see LICENSE.rst
"""
Load or make datasets for examples and tests.
"""

from .load import *    # noqa
from .make import *    # noqa
